--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Angular Velocity Sensor                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY vm_rot IS
  PORT(
    QUANTITY omega: OUT ANGULAR_VELOCITY; 
    TERMINAL rot1: ROTATIONAL_V);
END ENTITY vm_rot;
ARCHITECTURE behav OF vm_rot IS
  QUANTITY omega_val ACROSS rot1 TO rotational_v_ref;
  QUANTITY phi: ANGLE;
BEGIN
  omega_val == omega;
  omega == phi'dot;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Multiplier                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY MUL IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY MUL;
ARCHITECTURE behav OF MUL IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
    temp_val == INPUT0*INPUT1;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Torque Sensor                                            --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY fm_rot IS
  PORT(
    QUANTITY torque : OUT TORQUE;
    TERMINAL rot1, rot2 : ROTATIONAL_V);
END ENTITY fm_rot;
ARCHITECTURE behav OF fm_rot IS
  QUANTITY omega_zero ACROSS m_val THROUGH rot1 TO rot2;
BEGIN
  m_val == torque;
  omega_zero == 0.0;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Negator                                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY NEG IS
    GENERIC(TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY NEG;
ARCHITECTURE behav OF NEG IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
	temp_val == -INPUT;
	VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Summation                                                --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY SUM IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY SUM;
ARCHITECTURE behav OF SUM IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == INPUT0 + INPUT1;
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Limiter                                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY LMT IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL := 0.0;
          QUANTITY UL : IN REAL := 0.0;
          QUANTITY LL : IN REAL := 0.0;
          QUANTITY VAL : OUT REAL);
END ENTITY LMT;
ARCHITECTURE behav OF LMT IS
  QUANTITY temp_val : REAL := 0.0;
  SIGNAL lower_crossing : BOOLEAN := FALSE;
  SIGNAL upper_crossing : BOOLEAN := FALSE;
BEGIN
    ASSERT (UL >= LL) REPORT "Upper Limit should be greater than Lower limit" SEVERITY error;

    lower_crossing <= NOT INPUT'ABOVE(LL);
    upper_crossing <= INPUT'ABOVE(UL);
    BREAK ON lower_crossing;
    BREAK ON upper_crossing;

    IF ((lower_crossing) AND (INPUT < LL)) USE
        temp_val == LL;
    ELSIF ((upper_crossing) AND (INPUT > UL)) USE
        temp_val == UL;
    ELSE
        temp_val == INPUT;
    END USE;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Gain                                                     --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY GAIN IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT : IN REAL := 0.0;
          QUANTITY KP : IN REAL := 1.0;
          QUANTITY VAL : OUT REAL);
END ENTITY GAIN;
ARCHITECTURE behav OF GAIN IS
BEGIN
	VAL == KP*INPUT'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Damper                                                   --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY damp_rot IS
  PORT(
    QUANTITY damping : IN ANGULAR_DAMPING := 1.0;
    TERMINAL rot1, rot2 : ROTATIONAL_V);
END ENTITY damp_rot;
ARCHITECTURE beha OF damp_rot IS
  QUANTITY omega ACROSS m THROUGH rot1 TO rot2;
  QUANTITY phi : ANGLE;
BEGIN
  m == damping*omega;
  omega == phi'dot;
END ARCHITECTURE beha;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY Caliculate_Brake_Torque IS
	PORT (
		TERMINAL Brk_trq : ROTATIONAL_V;
		QUANTITY tgt_Trq_BK_CNT_Nm : IN REAL := 0.0;
		QUANTITY drv_idle_Driver : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Caliculate_Brake_Torque;

ARCHITECTURE struct OF Caliculate_Brake_Torque IS
	TERMINAL net_12 : ROTATIONAL_V;
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
BEGIN
	mul30 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_4 , input1 => 10000.0 , input0 => drv_idle_Driver );

	Brk_trq_masured : ENTITY WORK.fm_rot(behav)
		PORT MAP ( rot2 => net_12, rot1 => Brk_trq, torque => Q_8 );

	neg7 : ENTITY WORK.neg(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_7 , input => Q_8 );

	sum22 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_6 , input1 => tgt_Trq_BK_CNT_Nm , input0 => Q_7 );

	lmt37 : ENTITY WORK.lmt(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_5 , ll => 0.0 , ul => 1000.0 , input => Q_6 );

	sum2 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_3 , input1 => Q_4 , input0 => Q_5 );

	gain9 : ENTITY WORK.gain(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , kp => 1.0 , input => Q_3 );

	damp_rot11 : ENTITY WORK.damp_rot(beha)
		PORT MAP ( rot2 => rotational_velocity_ref, rot1 => net_12, damping => Q_2 );
END ARCHITECTURE struct;
----------------------------------------------------------------------

--///////////////////////////////////////////////////////////////////////////////////////////////////

--------------------------------------------------------------------------
--This model is modeled by  Digital Twins Inc. using component of the open source library created by AK-30, ANSYS and is covered by this license agreement. 

--This model was provided by  Digital Twins Inc. to METI as a social contribution. 
--This model including any updates, modifications, revisions, copies, and documentation are copyrighted works of the Digital Twins Inc. 

--THIS MODEL IS LICENSED TO YOU "AS IT IS" AND WITH NO WARRANTIES, EXPRESSED OR IMPLIED. ALL COMPANIES CONTRIBUTING TO THIS LIBRARY SPECIFICALLY DISCLAIM
-- ALL IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. 
--  Digital Twins Inc  AND ALL COMPANIES  MUST NOT HAVE ANY RESPONSIBILITY FOR ANY DAMAGES, FINANCIAL OR LEGAL CLAIMS WHATEVER.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            | Kimitoshi Tsuji    2-19.11.13 Digital Twins Inc. |         | 
-- ----------------------------------------------------------------------------


LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

---------- ENTITY DECLARATION ----------
ENTITY friction_rotational_v_02_a IS

       PORT (
				QUANTITY CTL: real   := 1.0;	--Load Equation Control CTL=1 Physical Equation
              QUANTITY M_SLIP: TORQUE   := 0.01;	--friction during slip mode [Nm]
              TERMINAL rot1: ROTATIONAL_V
       );

END ENTITY friction_rotational_v_02_a;
---------- ARCHITECTURE DECLARATION ----------
ARCHITECTURE behav OF friction_rotational_v_02_a IS

	QUANTITY omega ACROSS m THROUGH rot1 TO ROTATIONAL_V_REF;
BEGIN

if CTL > 0.0 use

	if (abs(omega)>1.0e-3) use
	    m == M_SLIP;
	ELSE
           m == 0.0;
	END USE;
else
	m==0.0;
end use;

END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY Caliculate_Drag_Resistance IS
	PORT (
		TERMINAL Brk_hikizuri_Trq : ROTATIONAL_V;
		QUANTITY Road_load_select_switch : IN REAL := 0.0;
		QUANTITY bk_trq_Hikizuri_brake : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Caliculate_Drag_Resistance;

ARCHITECTURE struct OF Caliculate_Drag_Resistance IS
	TERMINAL n0020 : ROTATIONAL_V;
	QUANTITY Q_2 : real := 0.0;
BEGIN
	friction_rotational_v_02_a1 : ENTITY WORK.friction_rotational_v_02_a(behav)
		PORT MAP ( rot1 => N0020, m_slip => bk_trq_Hikizuri_brake , ctl => Road_load_select_switch );

	fm_rot3 : ENTITY WORK.fm_rot(behav)
		PORT MAP ( rot2 => N0020, rot1 => Brk_hikizuri_Trq, torque => Q_2 );
END ARCHITECTURE struct;
----------------------------------------------------------------------


LIBRARY ieee;
USE ieee.all;

ENTITY BK_PNT IS
	PORT (
		TERMINAL MRV_BK_PNT : ROTATIONAL_V;
		QUANTITY tgt_Trq_BK_CNT_Nm : IN REAL := 0.0;
		QUANTITY Road_Load_Select_Switch : IN REAL := 0.0;
		QUANTITY drv_idle_Driver : IN REAL := 0.0 
	);
BEGIN 
END ENTITY BK_PNT;

ARCHITECTURE struct OF BK_PNT IS
	QUANTITY Q_2 : real := 0.0;
BEGIN
	vm_rot1 : ENTITY WORK.vm_rot(behav)
		PORT MAP ( rot1 => MRV_BK_PNT, omega => Q_2 );

	Caliculate_Brake_Torque: ENTITY WORK.Caliculate_Brake_Torque(struct)
		PORT MAP ( brk_trq => MRV_BK_PNT, tgt_Trq_BK_CNT_Nm => tgt_Trq_BK_CNT_Nm , drv_idle_Driver => drv_idle_Driver );

	Caliculate_Drag_Resistance: ENTITY WORK.Caliculate_Drag_Resistance(struct)
		PORT MAP ( brk_hikizuri_trq => MRV_BK_PNT, Road_load_select_switch => Road_Load_Select_Switch , bk_trq_Hikizuri_brake => 0.0 );
END ARCHITECTURE struct;
----------------------------------------------------------------------



