--///////////////////////////////////////////////////////////////////////////////////////////////////

---------- VHDLAMS MODEL battery_model ----------
LIBRARY IEEE;
--LIBRARY FUNDAMENTALS_VDA;

USE  IEEE.ELECTRICAL_SYSTEMS.ALL;
USE  IEEE.ENERGY_SYSTEMS.ALL;

USE  FUNDAMENTALS_VDA.TLU_VDA.ALL;

--library ths2_vda;
--use ths2_vda.tlu_vda.all;


---------- ENTITY DECLARATION battery_model ----------
ENTITY	battery_vhdl IS

GENERIC( INIT_TEMP : REAL := 25.0;-- Temparature C
         INIT_SOC  : REAL := 0.8;-- SOC 1 is 100%
         BAT_CAP   : REAL := 6.5);-- Battry Capacity AH

PORT(QUANTITY q_in_temp   :IN real := 25.0;
     QUANTITY q_out_soc   :OUT REAL ;
     QUANTITY q_out_ocv   :OUT VOLTAGE ;
     QUANTITY q_out_batv  :OUT VOLTAGE;
     QUANTITY q_out_wat   :OUT POWER;
     QUANTITY q_out_rwat  :OUT POWER;
     QUANTITY q_out_bati  :OUT CURRENT;
     QUANTITY q_out_ir    :OUT RESISTANCE;
     TERMINAL NP,NM       : ELECTRICAL);

END ENTITY battery_vhdl;

---------- ARCHITECTURE DECLARATION arch_battery_model ----------
ARCHITECTURE default OF battery_vhdl IS

--/ MAP DEFINITION /--

--/ OCV MAP                         /--
--/@input  SOC                      /--
--/@output OCV [Voltage]            /--
	CONSTANT SOC_VECTOR : REAL_VECTOR := (   0.0,   0.1,   0.2,   0.3,   0.4,   0.5,   0.6,   0.7,   0.8,   0.9,   1.0);			-- X

	CONSTANT OCV_VECTOR : REAL_VECTOR := (248.2,310.56,320.89,328.13,332.27,336.19,337.64,338.4,340.7,343.8,351.5);    -- 17.07.06 tsuji Li
--/ INERTIAL RESISTANCE               /--
--/@input  TEMP                       /--
--/@output inertial resistance [Ohm]  /--
    CONSTANT TEMP_VECTOR : REAL_VECTOR := (-30.0,-20.0,-10.0, 0.0,10.0, 20.0, 30.0, 40.0, 50.0, 60.0);
    CONSTANT IR_VECTOR   : REAL_VECTOR := (2.405,1.278,0.798,0.56,0.42,0.315,0.238,0.196,0.178,0.178);




--/ initialization constant/--
CONSTANT INIT_OCV : REAL := LOOKUP_1D(INIT_SOC , SOC_VECTOR, OCV_VECTOR);
CONSTANT INIT_IR  : REAL := LOOKUP_1D(INIT_TEMP, TEMP_VECTOR, IR_VECTOR);

--/ general constant /--
CONSTANT HOUR2SEC : REAL := 3600.0;

--/ INNER TERMINAL /--
TERMINAL NI : ELECTRICAL;

--/ BRANCH QUANTITY /--
QUANTITY BAT_V ACROSS             NP TO NM;
QUANTITY R_V   ACROSS             NP TO NI;
QUANTITY              R_I THROUGH NI TO NP;
QUANTITY OCV   ACROSS B_I THROUGH NI TO NM;

--/ INNER QUANTITY /--
QUANTITY SOC : REAL := INIT_SOC;


BEGIN

IF domain = quiescent_domain USE

SOC == INIT_SOC;
OCV == INIT_OCV;

R_I == 0.0;

q_out_soc  == INIT_SOC;
q_out_ocv  == INIT_OCV;
q_out_batv == INIT_OCV;
q_out_wat  == 0.0;
q_out_rwat == 0.0;
q_out_bati == 0.0;
q_out_ir   == INIT_IR;

ELSE


SOC == INIT_SOC - (R_I'integ/(BAT_CAP*HOUR2SEC));
OCV == LOOKUP_1D(SOC,SOC_VECTOR,OCV_VECTOR);
(-R_I) * LOOKUP_1D((q_in_temp-273.15),TEMP_VECTOR,IR_VECTOR) == R_V;

q_out_soc  == SOC;
q_out_ocv  == OCV;
q_out_batv == BAT_V;
q_out_wat  == R_I*BAT_V;
q_out_rwat == ABS(R_I*R_V);
q_out_bati == R_I;
q_out_ir   == LOOKUP_1D((q_in_temp-273.15),TEMP_VECTOR,IR_VECTOR);

END USE;


END ARCHITECTURE default;
---------- END VHDLAMS MODEL battery_model ----------

--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Thermal Resistance                                       --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.THERMAL_SYSTEMS.ALL;

ENTITY rth IS
  PORT(
    QUANTITY k : IN THERMAL_RESISTANCE := 1.0;
    TERMINAL th1, th2 : THERMAL);
END ENTITY rth;
ARCHITECTURE behav OF rth IS
  QUANTITY t ACROSS h THROUGH th1 TO th2;
BEGIN
  t == h*k;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Absolute Value                                           --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.ALL;

ENTITY fktabs IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL;
         QUANTITY VAL : OUT REAL);
END ENTITY fktabs;
ARCHITECTURE behav OF fktabs IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == abs(INPUT);
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Thermal Capacitance                                      --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.THERMAL_SYSTEMS.ALL;

ENTITY cth IS
  PORT(
    QUANTITY c_th : IN THERMAL_CAPACITANCE := 1.0; 
    QUANTITY t0 : IN TEMPERATURE := 293.0;
    TERMINAL th1 : THERMAL);
END ENTITY cth;
ARCHITECTURE behav OF cth IS
  QUANTITY t ACROSS h THROUGH th1 TO thermal_ref;
  QUANTITY h_int : real := t0;
BEGIN
  IF (domain = quiescent_domain) USE
    h_int == t0 * c_th;
    t == t0;
  ELSE
    h_int'dot == h;
    t == h_int / c_th;
  END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Temperature Source                                       --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.THERMAL_SYSTEMS.ALL;
USE IEEE.MECHANICAL_SYSTEMS.ALL;
USE IEEE.MATH_REAL.MATH_2_PI;

ENTITY t IS
  PORT(
    QUANTITY value : IN TEMPERATURE := 293.0;
    QUANTITY AC_MAG : IN TEMPERATURE := 1.0e-3;
    QUANTITY AC_PHASE : IN ANGLE := 0.0;
    TERMINAL th1 : THERMAL);
END ENTITY t;
ARCHITECTURE behav OF t IS
  QUANTITY t_val ACROSS h THROUGH th1 TO thermal_ref;
  QUANTITY ac_spec : real SPECTRUM AC_MAG, MATH_2_PI*AC_PHASE/360.0;
BEGIN
  IF (domain = quiescent_domain) OR (domain = time_domain) USE
    t_val == value;
  ELSE
    t_val == ac_spec;
  END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Thermometer                                              --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.THERMAL_SYSTEMS.ALL;

ENTITY thm IS
  PORT(
    QUANTITY temp: OUT TEMPERATURE;
    TERMINAL th1 : THERMAL);
END ENTITY thm;
ARCHITECTURE behav OF thm IS
  QUANTITY t ACROSS th1 TO thermal_ref;
BEGIN
  t == temp;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Heat Flow Source                                         --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.THERMAL_SYSTEMS.ALL;
USE IEEE.MECHANICAL_SYSTEMS.ALL;
USE IEEE.MATH_REAL.MATH_2_PI;

ENTITY h IS
  PORT(
    QUANTITY value : IN HEAT_FLOW := 1.0;
    QUANTITY AC_MAG : IN HEAT_FLOW := 1.0e-3;
    QUANTITY AC_PHASE : IN ANGLE := 0.0;
    TERMINAL th1, th2 : thermal);
END ENTITY h;
ARCHITECTURE behav OF h IS
  QUANTITY t ACROSS h_val THROUGH th1 TO th2;
  QUANTITY ac_spec : real SPECTRUM AC_MAG, MATH_2_PI*AC_PHASE/360.0;
BEGIN
  IF (domain = quiescent_domain) OR (domain = time_domain) USE
    h_val == value;
  ELSE
    h_val == ac_spec;
  END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY Battery_Tharmal IS
	PORT (
		QUANTITY T_BT_Hi_PNT_K : OUT REAL;
		QUANTITY BT_Hi_PNT_ambient_temp_K : IN REAL := 0.0;
		QUANTITY q_out_rwat : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Battery_Tharmal;

ARCHITECTURE struct OF Battery_Tharmal IS
	TERMINAL net_22 : THERMAL;
	TERMINAL n0066 : THERMAL;
	TERMINAL n0094 : THERMAL;
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
BEGIN
	rth_NiH_Battery : ENTITY WORK.rth(behav)
		PORT MAP ( th2 => N0094, th1 => net_22, k => 0.002 );

	fktabs1 : ENTITY WORK.fktabs(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , input => q_out_rwat );

	NiH_Battry_Thc : ENTITY WORK.cth(behav)
		PORT MAP ( th1 => N0094, t0 => BT_Hi_PNT_ambient_temp_K , c_th => 34188.0 );

	Eout : ENTITY WORK.t(behav)
		PORT MAP ( th1 => N0066, ac_phase => 0.0 , ac_mag => 0.000999999999976353 , value => BT_Hi_PNT_ambient_temp_K );

	temp_Battery : ENTITY WORK.thm(behav)
		PORT MAP ( th1 => N0094, temp => Q_3 );

	Qs_case : ENTITY WORK.rth(behav)
		PORT MAP ( th2 => N0066, th1 => N0094, k => 1.0 );

	h1 : ENTITY WORK.h(behav)
		PORT MAP ( th2 => net_22, th1 => thermal_ref, ac_phase => 0.0 , ac_mag => 0.001 , value => Q_2 );

	T_BT_Hi_PNT_K == Q_3;
END ARCHITECTURE struct;
----------------------------------------------------------------------


LIBRARY ieee;
USE ieee.all;

ENTITY BT_Hi_PNT IS
	PORT (
		TERMINAL EL_BT_Hi_PNT_m : ELECTRICAL;
		TERMINAL EL_BT_Hi_PNT_p : ELECTRICAL;
		QUANTITY SOC_BT_Hi_PNT : OUT REAL;
		QUANTITY T_BT_Hi_PNT_K : OUT REAL;
		QUANTITY BT_Hi_PNT_ambient_temp_K : IN REAL := 0.0;
		QUANTITY BT_Hi_PNT_init_SOC_per : IN REAL := 0.0;
		QUANTITY Temp_initial : IN REAL := 0.0;
		QUANTITY InOut0 : IN REAL := 0.0 
	);
BEGIN 
END ENTITY BT_Hi_PNT;

ARCHITECTURE struct OF BT_Hi_PNT IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
BEGIN
	Battery_Elec : ENTITY WORK.battery_vhdl(default)
		GENERIC MAP ( bat_cap => 48.5 , init_soc => BT_Hi_PNT_init_SOC_per/100.0 -- Expression
		, init_temp => 25.0 )
		PORT MAP ( nm => EL_BT_Hi_PNT_m, np => EL_BT_Hi_PNT_p, q_out_ir => Q_4 , q_out_bati => Q_5 , q_out_rwat => Q_3 , q_out_wat => Q_6 , q_out_batv => Q_7 , q_out_ocv => Q_8 , q_out_soc => Q_9 , q_in_temp => Q_2 );

	Battery_Tharmal: ENTITY WORK.Battery_Tharmal(struct)
		PORT MAP ( T_BT_Hi_PNT_K => Q_2 , BT_Hi_PNT_ambient_temp_K => BT_Hi_PNT_ambient_temp_K , q_out_rwat => Q_3 );

	T_BT_Hi_PNT_K == Q_2;
	SOC_BT_Hi_PNT == Q_9;
END ARCHITECTURE struct;
----------------------------------------------------------------------
