--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Voltmeter                                                --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;
                              
ENTITY VM IS
    PORT (QUANTITY V : OUT VOLTAGE;
          TERMINAL p,m : ELECTRICAL);
END ENTITY VM;
ARCHITECTURE behav of VM IS
    QUANTITY vg across p to m;
BEGIN
    V == vg;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Ammeter                                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;

ENTITY AM IS
    PORT (QUANTITY I : OUT CURRENT; 
          TERMINAL p,m : ELECTRICAL);
END ENTITY AM;
ARCHITECTURE behav of AM is
    QUANTITY v across ct through p to m;
BEGIN
    I == ct;
    v == 0.0;
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Capacitor                                                 --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------

LIBRARY IEEE;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;

ENTITY C IS
    GENERIC (V0     : VOLTAGE := 0.0;
			 Use_V0 : BOOLEAN := true);
    PORT (QUANTITY C : CAPACITANCE := 1.0e-6; 
          TERMINAL p,m  : ELECTRICAL);
END ENTITY C;
ARCHITECTURE behav OF c IS
    QUANTITY v ACROSS i THROUGH p TO m;
    QUANTITY charge : CHARGE := C*V0;
BEGIN
    IF (domain = quiescent_domain) USE
      if (Use_V0) use
		  charge == C*V0;
          v == V0;
	  else
		  charge == C*v;
    	  i == 0.0;
	  end use;
    ELSE
      charge == C * v ;
      i == charge'dot;
   END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Resistor                                                 --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------

LIBRARY IEEE;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;

ENTITY R IS
    PORT (QUANTITY R : RESISTANCE := 1.0e+3; 
          TERMINAL p,m  : ELECTRICAL);
END ENTITY R;
ARCHITECTURE behav OF R IS
    QUANTITY v ACROSS i THROUGH p TO m;
BEGIN
    v == i*R;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Multiplier                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY MUL IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY MUL;
ARCHITECTURE behav OF MUL IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
    temp_val == INPUT0*INPUT1;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Negator                                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY NEG IS
    GENERIC(TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY NEG;
ARCHITECTURE behav OF NEG IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
	temp_val == -INPUT;
	VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Summation                                                --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY SUM IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY SUM;
ARCHITECTURE behav OF SUM IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == INPUT0 + INPUT1;
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Integrator                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY INTG IS
    GENERIC (Y0 : REAL := 0.0;  
             TS : REAL := 0.0); 
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY KI : IN REAL := 1.0;
          QUANTITY VAL : OUT REAL := Y0);
END ENTITY INTG;
ARCHITECTURE behav OF INTG IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
    BREAK temp_val => Y0;
    temp_val'DOT == KI*INPUT;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Gain                                                     --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY GAIN IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT : IN REAL := 0.0;
          QUANTITY KP : IN REAL := 1.0;
          QUANTITY VAL : OUT REAL);
END ENTITY GAIN;
ARCHITECTURE behav OF GAIN IS
BEGIN
	VAL == KP*INPUT'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Limiter                                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY LMT IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL := 0.0;
          QUANTITY UL : IN REAL := 0.0;
          QUANTITY LL : IN REAL := 0.0;
          QUANTITY VAL : OUT REAL);
END ENTITY LMT;
ARCHITECTURE behav OF LMT IS
  QUANTITY temp_val : REAL := 0.0;
  SIGNAL lower_crossing : BOOLEAN := FALSE;
  SIGNAL upper_crossing : BOOLEAN := FALSE;
BEGIN
    ASSERT (UL >= LL) REPORT "Upper Limit should be greater than Lower limit" SEVERITY error;

    lower_crossing <= NOT INPUT'ABOVE(LL);
    upper_crossing <= INPUT'ABOVE(UL);
    BREAK ON lower_crossing;
    BREAK ON upper_crossing;

    IF ((lower_crossing) AND (INPUT < LL)) USE
        temp_val == LL;
    ELSIF ((upper_crossing) AND (INPUT > UL)) USE
        temp_val == UL;
    ELSE
        temp_val == INPUT;
    END USE;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Comparator                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY COMP IS
   GENERIC (TS : REAL := 0.0);
   PORT (QUANTITY INPUT : IN REAL := 0.0;
         QUANTITY VAL1 : IN REAL := 1.0;
         QUANTITY VAL2 : IN REAL := -1.0;
         QUANTITY THRES : IN REAL := 0.0;
         QUANTITY VAL : OUT REAL);
END ENTITY COMP;
ARCHITECTURE behav OF COMP IS
  QUANTITY temp_val : REAL := 0.0;
  SIGNAL crossing : BOOLEAN := FALSE;
BEGIN
    crossing <= NOT INPUT'ABOVE(THRES);
    IF (crossing AND (INPUT < THRES)) USE
        temp_val == VAL1;
    ELSE
        temp_val == VAL2;
    END USE;
    BREAK ON crossing;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY Step_down_control IS
	PORT (
		QUANTITY StepDown_Boost_Select_Switch : IN REAL := 0.0;
		QUANTITY DCDC_PNT_current_max_12V_A : IN REAL := 0.0;
		QUANTITY DCDC_PNT_tgt_volt_Lo_V : IN REAL := 0.0;
		QUANTITY volt_low : OUT REAL;
		QUANTITY volt_lowside : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Step_down_control;

ARCHITECTURE struct OF Step_down_control IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
BEGIN
	neg4 : ENTITY WORK.neg(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_8 , input => volt_lowside );

	sum6 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_7 , input1 => DCDC_PNT_tgt_volt_Lo_V , input0 => Q_8 );

	intg1 : ENTITY WORK.intg(behav)
		GENERIC MAP ( ts => 0.0 , y0 => 0.0 )
		PORT MAP ( val => Q_5 , ki => 10.0 , input => Q_7 );

	gain3 : ENTITY WORK.gain(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_6 , kp => 100.0 , input => Q_7 );

	sum5 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_4 , input1 => Q_5 , input0 => Q_6 );

	lmt3 : ENTITY WORK.lmt(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_3 , ll => 0.0 , ul => DCDC_PNT_current_max_12V_A , input => Q_4 );

	comp2 : ENTITY WORK.comp(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , thres => 0.5 , val2 => Q_3 , val1 => 0.0 , input => StepDown_Boost_Select_Switch );

	volt_low == Q_2;
END ARCHITECTURE struct;
----------------------------------------------------------------------

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Current Source                                           --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------

LIBRARY IEEE;
USE IEEE.MATH_REAL.MATH_2_PI;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY I IS 
    PORT (QUANTITY I : IN CURRENT := 1.0; 
          QUANTITY AC_MAG : IN CURRENT := 1.0e-3;
          QUANTITY AC_PHASE : IN ANGLE := 0.0;
          TERMINAL p,m: ELECTRICAL);
END ENTITY I;
ARCHITECTURE behav OF I IS
    QUANTITY v ACROSS ic THROUGH p TO m;
    QUANTITY ac_spec : real SPECTRUM AC_MAG, MATH_2_PI*AC_PHASE/360.0;
BEGIN
    IF (domain = quiescent_domain) OR (domain = time_domain) USE
	  ic == I;
    ELSE
      ic == ac_spec;
    END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY Boost_control IS
	PORT (
		QUANTITY StepDown_Boost_Select_Switch : IN REAL := 0.0;
		QUANTITY DCDC_PNT_current_max_250V_A : IN REAL := 0.0;
		QUANTITY DCDC_PNT_tgt_volt_Hi_V : IN REAL := 0.0;
		QUANTITY volt_high : OUT REAL;
		QUANTITY volt_highside : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Boost_control;

ARCHITECTURE struct OF Boost_control IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
BEGIN
	neg3 : ENTITY WORK.neg(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_6 , input => volt_highside );

	sum4 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_5 , input1 => DCDC_PNT_tgt_volt_Hi_V , input0 => Q_6 );

	gain2 : ENTITY WORK.gain(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_4 , kp => 1.0 , input => Q_5 );

	step_up_current : ENTITY WORK.lmt(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_3 , ll => 0.0 , ul => DCDC_PNT_current_max_250V_A , input => Q_4 );

	comp1 : ENTITY WORK.comp(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , thres => 0.5 , val2 => 0.0 , val1 => Q_3 , input => StepDown_Boost_Select_Switch );

	volt_high == Q_2;
END ARCHITECTURE struct;
----------------------------------------------------------------------


LIBRARY ieee;
USE ieee.all;

ENTITY Caliculate_Efficiency IS
	PORT (
		QUANTITY current_low : OUT REAL;
		QUANTITY volt_low : IN REAL := 0.0;
		QUANTITY current_high : OUT REAL;
		QUANTITY volt_high : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Caliculate_Efficiency;

ARCHITECTURE struct OF Caliculate_Efficiency IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
BEGIN
	st_u_voltage_ratio1 : ENTITY WORK.gain(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_5 , kp => 24.1379310344828 , input => volt_high );

	st_d_voltage_ratio1 : ENTITY WORK.gain(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_3 , kp => 0.0426470588235294 , input => volt_low );

	efficiency1 : ENTITY WORK.gain(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_4 , kp => 1.66666666666667 , input => Q_5 );

	effi1 : ENTITY WORK.gain(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , kp => 1.11111111111111 , input => Q_3 );

	current_low == Q_2;
	current_high == Q_4;
END ARCHITECTURE struct;
----------------------------------------------------------------------


LIBRARY ieee;
USE ieee.all;

ENTITY DCDC_PNT IS
	PORT (
		TERMINAL EL_DCDC_PNT_HGND : ELECTRICAL;
		TERMINAL EL_DCDC_PNT_HBT : ELECTRICAL;
		TERMINAL EL_DCDC_PNT_LGND : ELECTRICAL;
		TERMINAL EL_DCDC_PNT_LBT : ELECTRICAL;
		QUANTITY StepDown_Boost_Select_Switch : IN REAL := 0.0;
		QUANTITY DCDC_PNT_tgt_volt_Hi_V : IN REAL := 0.0;
		QUANTITY DCDC_PNT_current_max_250V_A : IN REAL := 0.0;
		QUANTITY DCDC_PNT_tgt_volt_Lo_V : IN REAL := 0.0;
		QUANTITY DCDC_PNT_current_max_12V_A : IN REAL := 0.0 
	);
BEGIN 
END ENTITY DCDC_PNT;

ARCHITECTURE struct OF DCDC_PNT IS
	TERMINAL net_27 : ELECTRICAL;
	TERMINAL net_31 : ELECTRICAL;
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
	QUANTITY Q_10 : real := 0.0;
	QUANTITY Q_11 : real := 0.0;
BEGIN
	volt_dcdc_out : ENTITY WORK.vm(behav)
		PORT MAP ( m => EL_DCDC_PNT_LGND, p => net_27, v => Q_9 );

	current_dcdc_highside : ENTITY WORK.am(behav)
		PORT MAP ( m => net_31, p => EL_DCDC_PNT_HBT, i => Q_8 );

	current_dcdc_lowside : ENTITY WORK.am(behav)
		PORT MAP ( m => EL_DCDC_PNT_LBT, p => net_27, i => Q_11 );

	dcdc_capacitor1 : ENTITY WORK.c(behav)
		GENERIC MAP ( use_v0 => true , v0 => 0.0 )
		PORT MAP ( m => EL_DCDC_PNT_HGND, p => EL_DCDC_PNT_HBT, c => 0.0066 );

	volt_dcdc_highside_capa1 : ENTITY WORK.vm(behav)
		PORT MAP ( m => EL_DCDC_PNT_HGND, p => EL_DCDC_PNT_HBT, v => Q_6 );

	r2 : ENTITY WORK.r(behav)
		PORT MAP ( m => EL_DCDC_PNT_HGND, p => EL_DCDC_PNT_HBT, r => 100000.0 );

	r1 : ENTITY WORK.r(behav)
		PORT MAP ( m => EL_DCDC_PNT_LGND, p => EL_DCDC_PNT_LBT, r => 100000.0 );

	power_dcdc_lowside : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_10 , input1 => Q_9 , input0 => Q_11 );

	Step_down_control: ENTITY WORK.Step_down_control(struct)
		PORT MAP ( StepDown_Boost_Select_Switch => StepDown_Boost_Select_Switch , DCDC_PNT_current_max_12V_A => DCDC_PNT_current_max_12V_A , DCDC_PNT_tgt_volt_Lo_V => DCDC_PNT_tgt_volt_Lo_V , volt_low => Q_4 , volt_lowside => Q_9 );

	i8 : ENTITY WORK.i(behav)
		PORT MAP ( m => net_27, p => EL_DCDC_PNT_LGND, ac_phase => 0.0 , ac_mag => 0.001 , i => Q_4 );

	power_dcdc_highside : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_7 , input1 => Q_8 , input0 => Q_6 );

	Boost_control: ENTITY WORK.Boost_control(struct)
		PORT MAP ( StepDown_Boost_Select_Switch => StepDown_Boost_Select_Switch , DCDC_PNT_current_max_250V_A => DCDC_PNT_current_max_250V_A , DCDC_PNT_tgt_volt_Hi_V => DCDC_PNT_tgt_volt_Hi_V , volt_high => Q_5 , volt_highside => Q_6 );

	i6 : ENTITY WORK.i(behav)
		PORT MAP ( m => net_31, p => EL_DCDC_PNT_HGND, ac_phase => 0.0 , ac_mag => 0.001 , i => Q_5 );

	Caliculate_Efficiency: ENTITY WORK.Caliculate_Efficiency(struct)
		PORT MAP ( current_low => Q_3 , volt_low => Q_4 , current_high => Q_2 , volt_high => Q_5 );

	i7 : ENTITY WORK.i(behav)
		PORT MAP ( m => EL_DCDC_PNT_HGND, p => net_31, ac_phase => 0.0 , ac_mag => 0.001 , i => Q_3 );

	i3 : ENTITY WORK.i(behav)
		PORT MAP ( m => EL_DCDC_PNT_LGND, p => net_27, ac_phase => 0.0 , ac_mag => 0.001 , i => Q_2 );
END ARCHITECTURE struct;
----------------------------------------------------------------------


