--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Gain                                                     --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY GAIN IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT : IN REAL := 0.0;
          QUANTITY KP : IN REAL := 1.0;
          QUANTITY VAL : OUT REAL);
END ENTITY GAIN;
ARCHITECTURE behav OF GAIN IS
BEGIN
	VAL == KP*INPUT'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Delay                                                    --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY DELAY IS
    GENERIC (Y0 : REAL := 0.0;
             TD : REAL := 1.0e-3);
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY DELAY;
ARCHITECTURE behav OF DELAY IS
BEGIN
  IF (DOMAIN = QUIESCENT_DOMAIN) USE
    VAL == Y0;
  ELSIF (DOMAIN = TIME_DOMAIN) USE
    IF (NOW < TD) USE
      VAL == Y0;
    ELSE
      VAL == INPUT'DELAYED(TD);
    END USE;
  ELSE
    VAL == INPUT'DELAYED(TD);
  END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--------------------------------------------------------------------------
--This model is modeled by  Digital Twins Inc. using component of the open source library created by AK-30, ANSYS and is covered by this license agreement. 

--This model was provided by  Digital Twins Inc. to METI as a social contribution. 
--This model including any updates, modifications, revisions, copies, and documentation are copyrighted works of the Digital Twins Inc. 

--THIS MODEL IS LICENSED TO YOU "AS IT IS" AND WITH NO WARRANTIES, EXPRESSED OR IMPLIED. ALL COMPANIES CONTRIBUTING TO THIS LIBRARY SPECIFICALLY DISCLAIM
-- ALL IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. 
--  Digital Twins Inc  AND ALL COMPANIES  MUST NOT HAVE ANY RESPONSIBILITY FOR ANY DAMAGES, FINANCIAL OR LEGAL CLAIMS WHATEVER.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            | Kimitoshi Tsuji    2-19.11.13 Digital Twins Inc. |         | 
-- ----------------------------------------------------------------------------


LIBRARY IEEE;
USE IEEE.MATH_REAL.ALL;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY driving_judg IS
--    GENERIC ( );
    PORT (QUANTITY vel          : IN  Velocity := 0.0 ;
          QUANTITY vel_d         : IN  Velocity := 0.0 ;
         
			 QUANTITY x_accel      : OUT  real;
          QUANTITY x_slowdown   : OUT  real;
          QUANTITY x_idle       : OUT  real);

END ENTITY driving_judg;
ARCHITECTURE behav OF driving_judg IS

	quantity vvel : real ; 
	quantity acc : real ;
BEGIN

	vvel == vel ; 
--	acc== vel'dot ; 
	acc== vel-vel_d ; 
	break on acc'above(0.0), vvel'above(0.0) ;

 -- flag_accel
    IF( acc > 0.0 ) USE
        x_accel == 1.0;
    ELSE
        x_accel == 0.0;
    END USE;

 -- flag_slowdown
    IF( acc < 0.0 ) USE
        x_slowdown == 1.0;
    ELSE
        x_slowdown == 0.0;
    END USE;

 -- flag_idle
    IF( vvel > 0.0 ) USE
        x_idle == 0.0;
    ELSE
        x_idle == 1.0;
    END USE;

END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY Caliculate_Driving_State IS
	PORT (
		QUANTITY drv_slowdown : OUT REAL;
		QUANTITY accel_rate_Driver : OUT REAL;
		QUANTITY drv_idle_Driver : OUT REAL;
		QUANTITY tgt_v_kmph : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Caliculate_Driving_State;

ARCHITECTURE struct OF Caliculate_Driving_State IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
BEGIN
	delay1 : ENTITY WORK.delay(behav)
		GENERIC MAP ( td => 0.001 , y0 => 0.0 )
		PORT MAP ( val => Q_5 , input => tgt_v_kmph );

	judge_driving : ENTITY WORK.driving_judg(behav)
		PORT MAP ( x_idle => Q_2 , x_slowdown => Q_3 , x_accel => Q_4 , vel_d => Q_5 , vel => tgt_v_kmph );

	drv_idle_Driver == Q_2;
	drv_slowdown == Q_3;
	accel_rate_Driver == Q_4;
END ARCHITECTURE struct;
----------------------------------------------------------------------

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Negator                                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY NEG IS
    GENERIC(TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY NEG;
ARCHITECTURE behav OF NEG IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
	temp_val == -INPUT;
	VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Summation                                                --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY SUM IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY SUM;
ARCHITECTURE behav OF SUM IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == INPUT0 + INPUT1;
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Limiter                                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY LMT IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL := 0.0;
          QUANTITY UL : IN REAL := 0.0;
          QUANTITY LL : IN REAL := 0.0;
          QUANTITY VAL : OUT REAL);
END ENTITY LMT;
ARCHITECTURE behav OF LMT IS
  QUANTITY temp_val : REAL := 0.0;
  SIGNAL lower_crossing : BOOLEAN := FALSE;
  SIGNAL upper_crossing : BOOLEAN := FALSE;
BEGIN
    ASSERT (UL >= LL) REPORT "Upper Limit should be greater than Lower limit" SEVERITY error;

    lower_crossing <= NOT INPUT'ABOVE(LL);
    upper_crossing <= INPUT'ABOVE(UL);
    BREAK ON lower_crossing;
    BREAK ON upper_crossing;

    IF ((lower_crossing) AND (INPUT < LL)) USE
        temp_val == LL;
    ELSIF ((upper_crossing) AND (INPUT > UL)) USE
        temp_val == UL;
    ELSE
        temp_val == INPUT;
    END USE;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

-- ----------------------------------------------------------------------------
-- Copyright (C) 2004-2011 VDA/FAT
--
-- This model is a component of the open source library created by the VDA/FAT 
-- working group number 30 and is covered by this license agreement. This model
-- including any updates, modifications, revisions, copies, and documentation
-- are copyrighted works of the VDA/FAT. Use of this model indicates your
-- complete and unconditional acceptance of the terms and conditions set forth
-- in this license agreement.
--  
-- The VDA/FAT grants a non-exclusive license to use, reproduce, modify and
-- distribute this model under the condition, that:
-- (a) no fee or other consideration is charged for any distribution except 
--     compilations distributed in accordance with Section (d) of this license 
--     agreement;
-- (b) the comment text embedded in this model is included verbatim in each
--     copy of this model made or distributed by you, whether or not such
--     version is modified;
-- (c) any modified version must include a conspicuous notice that this model
--     has been modified and the date of modification; and
-- (d) any compilations sold by you that include this model must include a 
--     conspicuous notice that this model is available from the VDA/FAT in 
--     its original form at no charge.
--
-- THIS MODEL IS LICENSED TO YOU "AS IT IS" AND WITH NO WARRANTIES, EXPRESSED
-- OR IMPLIED. THE VDA/FAT AND ALL COMPANIES CONTRIBUTING TO THIS LIBRARY
-- SPECIFICALLY DISCLAIM ALL IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
-- FOR A PARTICULAR PURPOSE. THE VDA/FAT AND ALL COMPANIES ORGANIZED WITHIN
-- MUST NOT HAVE ANY RESPONSIBILITY FOR ANY DAMAGES, FINANCIAL OR LEGAL CLAIMS 
-- WHATEVER.
-- ----------------------------------------------------------------------------
-- Literature:
-- Fritzson, P.: Object-Oriented Modeling and Simulation with Modelica 2.1
-- IEEE Press, 2004.
--  
-- Dependencies: 
-- --------------------------------------------------------------------
-- Logical Library         Design unit
-- --------------------------------------------------------------------
--
--
-- Author(s):
-- Joachim Haase 
--
-- Validator:
-- 
--
-- Source:
-- q_firstorder_vda.vhd
--
-- Development simulator:
-- SystemVision Professional 
--
-- Tested on: 
-- ------------------------------------------------------------------
-- Version  Simulator      Version   OS    Validator      Date
-- ------------------------------------------------------------------
-- 1.1      
--
--
-- Modification History:
-- ------------------------------------------------------------------
-- Version  Author            Date           Description
-- ------------------------------------------------------------------
--  1.1    Joachim Haase      2005/02/06     Original Version     
-- 
--
-- ----------------------------------------------------------------------------
-- $Version: 3.0.0 $
-- $Revision: 2627 $
-- $Date: 2010-12-20 19:11:06 +0100 (Mon, 20 Dec 2010) $
-- $Author: andre $
-- ----------------------------------------------------------------------------
	

--/**
--	
-- First Order Transfer Function Block.
-- The model defines a first order system Q_OUT(s) = K/(T*s+1.0)*Q_IN(s).
-- <p>Name and functionality in accordance with Modelica.</p>
-- 
-- @generic   K	 gain []
-- @generic   T	 time constant  [s]
-- 
-- @port      Q_IN	 input port
-- @port      Q_OUT	 output port
--	
-- @library   FUNDAMENTALS_VDA
-- @structure control_systems/basic
-- @test      basic_test
-- @reference Fritzson, P.: Object-Oriented Modeling and Simulation with Modelica 2.1
--            IEEE Press, 2004.
--
--*/					



 
entity Q_FIRSTORDER_VDA is
   generic  (
      K   : REAL := 1.0;
      T   : REAL := 1.0   -- time constant [s]
      );
   port     (
      quantity Q_IN  : in  REAL;
      quantity Q_OUT : out REAL   -- output port
      );
end entity Q_FIRSTORDER_VDA;

architecture BASIC of Q_FIRSTORDER_VDA is 
  constant NUM : REAL_VECTOR := (0 => K);
  constant DEN : REAL_VECTOR := (1.0, T);
begin
  Q_OUT == Q_IN'LTF(NUM, DEN);
end architecture BASIC;
-- ----------------------------------------------------------------------------
-- Copyright (C) 2004-2011 VDA/FAT
-- ----------------------------------------------------------------------------


--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY Caliculate_Opeining_Accel IS
	PORT (
		QUANTITY accel_rate_Driver : OUT REAL;
		QUANTITY Driver_gain_accel : IN REAL := 0.0;
		QUANTITY difference_velocity : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Caliculate_Opeining_Accel;

ARCHITECTURE struct OF Caliculate_Opeining_Accel IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
BEGIN
	gain3 : ENTITY WORK.gain(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_4 , kp => Driver_gain_accel , input => difference_velocity );

	lmt1 : ENTITY WORK.lmt(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_3 , ll => 0.0 , ul => 1.0 , input => Q_4 );

	q_firstorder_vda1 : ENTITY WORK.q_firstorder_vda(basic)
		GENERIC MAP ( t => 0.1 , k => 1.0 )
		PORT MAP ( q_out => Q_2 , q_in => Q_3 );

	accel_rate_Driver == Q_2;
END ARCHITECTURE struct;
----------------------------------------------------------------------

--///////////////////////////////////////////////////////////////////////////////////////////////////

--------------------------------------------------------------------------
--This model is modeled by  Digital Twins Inc. using component of the open source library created by AK-30, ANSYS and is covered by this license agreement. 

--This model was provided by  Digital Twins Inc. to METI as a social contribution. 
--This model including any updates, modifications, revisions, copies, and documentation are copyrighted works of the Digital Twins Inc. 

--THIS MODEL IS LICENSED TO YOU "AS IT IS" AND WITH NO WARRANTIES, EXPRESSED OR IMPLIED. ALL COMPANIES CONTRIBUTING TO THIS LIBRARY SPECIFICALLY DISCLAIM
-- ALL IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. 
--  Digital Twins Inc  AND ALL COMPANIES  MUST NOT HAVE ANY RESPONSIBILITY FOR ANY DAMAGES, FINANCIAL OR LEGAL CLAIMS WHATEVER.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            | Kimitoshi Tsuji    2-19.11.13 Digital Twins Inc. |         | 
-- ----------------------------------------------------------------------------




LIBRARY IEEE;
USE IEEE.MATH_REAL.ALL;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY brake_ctrl IS
--    GENERIC ( );
    PORT (QUANTITY x_idle         : IN  real     := 0.0 ;
          QUANTITY x_accel        : IN  real     := 0.0 ;
          QUANTITY x_slowdown     : IN  real     := 0.0 ;
          QUANTITY trq_brake_in   : IN  TORQUE   := 0.0 ;
          QUANTITY trq_brake      : OUT TORQUE);

END ENTITY brake_ctrl;
ARCHITECTURE behav OF brake_ctrl IS

BEGIN

    IF ( x_slowdown = 1.0 ) USE

        trq_brake == trq_brake_in;

    ELSE

        trq_brake == 0.0;

    END USE;

END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY Caliculate_Opening_Brake IS
	PORT (
		QUANTITY drv_slowdown : IN REAL := 0.0;
		QUANTITY brake_rate_Driver : OUT REAL;
		QUANTITY drv_idle_Driver : IN REAL := 0.0;
		QUANTITY Driver_gain_brake : IN REAL := 0.0;
		QUANTITY difference_velocity : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Caliculate_Opening_Brake;

ARCHITECTURE struct OF Caliculate_Opening_Brake IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
BEGIN
	neg3 : ENTITY WORK.neg(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_5 , input => difference_velocity );

	lmt3 : ENTITY WORK.lmt(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_4 , ll => 0.0 , ul => 100.0 , input => Q_5 );

	gain2 : ENTITY WORK.gain(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_3 , kp => Driver_gain_brake , input => Q_4 );

	brake_control : ENTITY WORK.brake_ctrl(behav)
		PORT MAP ( trq_brake => Q_2 , trq_brake_in => Q_3 , x_slowdown => drv_slowdown , x_idle => drv_idle_Driver );

	brake_rate_Driver == Q_2;
END ARCHITECTURE struct;
----------------------------------------------------------------------


LIBRARY ieee;
USE ieee.all;

ENTITY Driver IS
	PORT (
		QUANTITY brake_rate_Driver : OUT REAL;
		QUANTITY accel_rate_Driver : OUT REAL;
		QUANTITY drv_idle_Driver : OUT REAL;
		QUANTITY Driver_gain_brake : IN REAL := 0.0;
		QUANTITY Driver_gain_accel : IN REAL := 0.0;
		QUANTITY v_VL_PNT_mps : IN REAL := 0.0;
		QUANTITY tgt_v_kmph : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Driver;

ARCHITECTURE struct OF Driver IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
	QUANTITY Q_8 : real := 0.0;
	QUANTITY Q_9 : real := 0.0;
BEGIN
	ms2kmh : ENTITY WORK.gain(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_8 , kp => 3.6 , input => v_VL_PNT_mps );

	Caliculate_Driving_State: ENTITY WORK.Caliculate_Driving_State(struct)
		PORT MAP ( drv_slowdown => Q_2 , accel_rate_Driver => Q_9 , drv_idle_Driver => Q_4 , tgt_v_kmph => tgt_v_kmph );

	neg1 : ENTITY WORK.neg(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_7 , input => Q_8 );

	sum1 : ENTITY WORK.sum(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_5 , input1 => tgt_v_kmph , input0 => Q_7 );

	Caliculate_Opeining_Accel: ENTITY WORK.Caliculate_Opeining_Accel(struct)
		PORT MAP ( accel_rate_Driver => Q_6 , Driver_gain_accel => Driver_gain_accel , difference_velocity => Q_5 );

	Caliculate_Opening_Brake: ENTITY WORK.Caliculate_Opening_Brake(struct)
		PORT MAP ( drv_slowdown => Q_2 , brake_rate_Driver => Q_3 , drv_idle_Driver => Q_4 , Driver_gain_brake => Driver_gain_brake , difference_velocity => Q_5 );

	brake_rate_Driver == Q_3;
	drv_idle_Driver == Q_4;
	accel_rate_Driver == Q_6;
END ARCHITECTURE struct;
----------------------------------------------------------------------




