--///////////////////////////////////////////////////////////////////////////////////////////////////

--------------------------------------------------------------------------
--This model is modeled by  Digital Twins Inc. using component of the open source library created by AK-30, ANSYS and is covered by this license agreement. 

--This model was provided by  Digital Twins Inc. to METI as a social contribution. 
--This model including any updates, modifications, revisions, copies, and documentation are copyrighted works of the Digital Twins Inc. 

--THIS MODEL IS LICENSED TO YOU "AS IT IS" AND WITH NO WARRANTIES, EXPRESSED OR IMPLIED. ALL COMPANIES CONTRIBUTING TO THIS LIBRARY SPECIFICALLY DISCLAIM
-- ALL IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. 
--  Digital Twins Inc  AND ALL COMPANIES  MUST NOT HAVE ANY RESPONSIBILITY FOR ANY DAMAGES, FINANCIAL OR LEGAL CLAIMS WHATEVER.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            | Kimitoshi Tsuji    2-19.11.13 Digital Twins Inc. |         | 
-- ----------------------------------------------------------------------------


LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;
USE IEEE.MATH_REAL.ALL;

ENTITY IDEAL_GEAR2 IS
	GENERIC(
	--	R             : REAL :=1.0 ;
		N1_0          : REAL :=0.0 ;
		PHI1_0,PHI2_0 : ANGLE :=0.0 );
	PORT(
		QUANTITY Ratio    : IN REAL := 0.0; 
		TERMINAL ROT1,ROT2 : ROTATIONAL_V ;
		QUANTITY Power_i,Power_o : OUT real;
		QUANTITY PHI1,PHI2 : OUT ANGLE     ;
		QUANTITY N1,N2     : OUT REAL     );
END ENTITY;
ARCHITECTURE BEHAV OF IDEAL_GEAR2 IS
	CONSTANT N2OM : REAL := 2.0 * MATH_PI / 60.0 ; --rpm TO rad/s
	CONSTANT OM2N : REAL := 60.0 / ( 2.0 * MATH_PI ) ; --rad/s TO rpm
    QUANTITY omega_i  ACROSS torque_i  THROUGH rot1 to ROTATIONAL_V_REF;
    QUANTITY omega_o  ACROSS torque_o  THROUGH ROTATIONAL_V_REF to rot2;

BEGIN
	BREAK
		PHI1 => PHI1_0 ,
		PHI2 => PHI2_0 ,
		omega_i => N1_0 * N2OM ;

	--omega_o == omega_i / R;
    omega_i == -omega_o * Ratio ; 
	torque_o == torque_i * Ratio ;

	PHI1 == omega_i'INTEG + PHI1_0 ;
	PHI2 == omega_o'INTEG + PHI2_0 ;

	N1 == omega_i * OM2N ;
	N2 == omega_o * OM2N ;
  
    Power_i == omega_i * torque_i;
    Power_o == omega_o * torque_o;

END ARCHITECTURE BEHAV;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Wattmeter                                                --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;
USE IEEE.ENERGY_SYSTEMS.POWER;

ENTITY wm_rot IS
  PORT(
    QUANTITY power : OUT POWER;
    TERMINAL rotv1, rotv2, rotm1, rotm2 : rotational_v);
END ENTITY wm_rot;
ARCHITECTURE behav OF wm_rot IS
  QUANTITY omega_in ACROSS rotv1 TO rotv2;
  QUANTITY omega_zero ACROSS m THROUGH rotm1 TO rotm2;
  QUANTITY phi_in : ANGULAR_VELOCITY;
BEGIN
  omega_zero == 0.0;
  power == m*omega_in;
  omega_in == phi_in'dot;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Multiplier                                               --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY MUL IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT0,INPUT1 : IN REAL;
          QUANTITY VAL : OUT REAL);
END ENTITY MUL;
ARCHITECTURE behav OF MUL IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
    temp_val == INPUT0*INPUT1;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Damper                                                   --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY damp_rot IS
  PORT(
    QUANTITY damping : IN ANGULAR_DAMPING := 1.0;
    TERMINAL rot1, rot2 : ROTATIONAL_V);
END ENTITY damp_rot;
ARCHITECTURE beha OF damp_rot IS
  QUANTITY omega ACROSS m THROUGH rot1 TO rot2;
  QUANTITY phi : ANGLE;
BEGIN
  m == damping*omega;
  omega == phi'dot;
END ARCHITECTURE beha;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY Gear_Mecha_Loss IS
	PORT (
		TERMINAL rotv1 : ROTATIONAL_V;
		QUANTITY FG_PNT_Mecha_loss_W : IN REAL := 0.0;
		QUANTITY Road_load_select_switch : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Gear_Mecha_Loss;

ARCHITECTURE struct OF Gear_Mecha_Loss IS
	TERMINAL net_39 : ROTATIONAL_V;
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
BEGIN
	Power_mecha_loss : ENTITY WORK.wm_rot(behav)
		PORT MAP ( rotm2 => net_39, rotm1 => rotv1, rotv2 => rotational_velocity_ref, rotv1 => rotv1, power => Q_3 );

	mul9 : ENTITY WORK.mul(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_2 , input1 => Road_load_select_switch , input0 => FG_PNT_Mecha_loss_W );

	Mecha_loss : ENTITY WORK.damp_rot(beha)
		PORT MAP ( rot2 => rotational_velocity_ref, rot1 => net_39, damping => Q_2 );
END ARCHITECTURE struct;
----------------------------------------------------------------------


LIBRARY ieee;
USE ieee.all;

ENTITY FG_PNT IS
	PORT (
		TERMINAL MRV_FG_PNT_UP : ROTATIONAL_V;
		TERMINAL MRV_FG_PNT_DN : ROTATIONAL_V;
		QUANTITY FG_PNT_gear_ratio : IN REAL := 0.0;
		QUANTITY FG_PNT_Mecha_loss_W : IN REAL := 0.0;
		QUANTITY Road_load_select_switch : IN REAL := 0.0 
	);
BEGIN 
END ENTITY FG_PNT;

ARCHITECTURE struct OF FG_PNT IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
BEGIN
	gear_conversion : ENTITY WORK.ideal_gear2(behav)
		PORT MAP ( rot2 => MRV_FG_PNT_DN, rot1 => MRV_FG_PNT_UP, n2 => Q_2 , n1 => Q_3 , phi2 => Q_4 , phi1 => Q_5 , power_o => Q_6 , power_i => Q_7 , ratio => FG_PNT_gear_ratio );

	Gear_Mecha_Loss: ENTITY WORK.Gear_Mecha_Loss(struct)
		PORT MAP ( rotv1 => MRV_FG_PNT_UP, FG_PNT_Mecha_loss_W => FG_PNT_Mecha_loss_W , Road_load_select_switch => Road_load_select_switch );
END ARCHITECTURE struct;
----------------------------------------------------------------------


