--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Mass                                                     --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY mass_rot IS
  GENERIC(
    phi0  : ANGLE := 0.0;
    omega0 : ANGULAR_VELOCITY := 0.0);
  PORT(
        QUANTITY j : MOMENT_INERTIA := 1.0;
        TERMINAL rot1 : ROTATIONAL_V );
END ENTITY mass_rot;
ARCHITECTURE behav of mass_rot IS
  QUANTITY omega ACROSS m THROUGH rot1 TO rotational_v_ref;
  QUANTITY phi : ANGLE;
  QUANTITY acc : ANGULAR_ACCELERATION;
BEGIN
  IF (domain = quiescent_domain) USE
    phi == phi0;
    omega == omega0;
  ELSE
    phi'dot == omega;
    omega'dot == acc;
  END USE;
    m == j*acc;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Angular Velocity Sensor                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY vm_rot IS
  PORT(
    QUANTITY omega: OUT ANGULAR_VELOCITY; 
    TERMINAL rot1: ROTATIONAL_V);
END ENTITY vm_rot;
ARCHITECTURE behav OF vm_rot IS
  QUANTITY omega_val ACROSS rot1 TO rotational_v_ref;
  QUANTITY phi: ANGLE;
BEGIN
  omega_val == omega;
  omega == phi'dot;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Torque Source                                            --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;
USE IEEE.MATH_REAL.MATH_2_PI;

ENTITY f_rot IS
  PORT(
    QUANTITY value : TORQUE := 1.0;
    QUANTITY AC_MAG : IN TORQUE := 1.0e-3;
    QUANTITY AC_PHASE : IN ANGLE := 0.0;
    TERMINAL rot1, rot2 : rotational_v);
END ENTITY f_rot;
ARCHITECTURE behav OF f_rot IS
  QUANTITY omega ACROSS m THROUGH rot1 TO rot2;
  QUANTITY phi : ANGLE;
  QUANTITY ac_spec : real SPECTRUM AC_MAG, MATH_2_PI*AC_PHASE/360.0;
BEGIN
  IF (domain = quiescent_domain) OR (domain = time_domain) USE
    m == value;
    omega == phi'dot;
  ELSE
    m == ac_spec;
    omega == phi'dot;
  END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Torque Sensor                                            --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY fm_rot IS
  PORT(
    QUANTITY torque : OUT TORQUE;
    TERMINAL rot1, rot2 : ROTATIONAL_V);
END ENTITY fm_rot;
ARCHITECTURE behav OF fm_rot IS
  QUANTITY omega_zero ACROSS m_val THROUGH rot1 TO rot2;
BEGIN
  m_val == torque;
  omega_zero == 0.0;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Wattmeter                                                --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;
USE IEEE.ENERGY_SYSTEMS.POWER;

ENTITY wm_rot IS
  PORT(
    QUANTITY power : OUT POWER;
    TERMINAL rotv1, rotv2, rotm1, rotm2 : rotational_v);
END ENTITY wm_rot;
ARCHITECTURE behav OF wm_rot IS
  QUANTITY omega_in ACROSS rotv1 TO rotv2;
  QUANTITY omega_zero ACROSS m THROUGH rotm1 TO rotm2;
  QUANTITY phi_in : ANGULAR_VELOCITY;
BEGIN
  omega_zero == 0.0;
  power == m*omega_in;
  omega_in == phi_in'dot;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY MotorGenerator_Mecha IS
	PORT (
		TERMINAL MRV_MG_PNT : ROTATIONAL_V;
		QUANTITY tgt_Trq_MG_CNT_Nm : IN REAL := 0.0;
		QUANTITY tmg2 : OUT REAL;
		QUANTITY nmg2 : OUT REAL 
	);
BEGIN 
END ENTITY MotorGenerator_Mecha;

ARCHITECTURE struct OF MotorGenerator_Mecha IS
	TERMINAL net_17 : ROTATIONAL_V;
	TERMINAL n0138 : ROTATIONAL_V;
	TERMINAL net_18 : ROTATIONAL_V;
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
BEGIN
	mass_MG2 : ENTITY WORK.mass_rot(behav)
		GENERIC MAP ( omega0 => 0.0 , phi0 => 0.0 )
		PORT MAP ( rot1 => net_17, j => 0.0234 );

	vm_rot1 : ENTITY WORK.vm_rot(behav)
		PORT MAP ( rot1 => N0138, omega => Q_5 );

	f_rot1 : ENTITY WORK.f_rot(behav)
		PORT MAP ( rot2 => net_18, rot1 => rotational_velocity_ref, ac_phase => 0.0 , ac_mag => 0.001 , value => tgt_Trq_MG_CNT_Nm );

	fm_rot1 : ENTITY WORK.fm_rot(behav)
		PORT MAP ( rot2 => N0138, rot1 => net_18, torque => Q_4 );

	fm_rot2 : ENTITY WORK.fm_rot(behav)
		PORT MAP ( rot2 => MRV_MG_PNT, rot1 => net_17, torque => Q_3 );

	wm_rot1 : ENTITY WORK.wm_rot(behav)
		PORT MAP ( rotm2 => net_17, rotm1 => N0138, rotv2 => rotational_velocity_ref, rotv1 => N0138, power => Q_2 );

	tmg2 == Q_4;
	nmg2 == Q_5;
END ARCHITECTURE struct;
----------------------------------------------------------------------

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Voltmeter                                                --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;
                              
ENTITY VM IS
    PORT (QUANTITY V : OUT VOLTAGE;
          TERMINAL p,m : ELECTRICAL);
END ENTITY VM;
ARCHITECTURE behav of VM IS
    QUANTITY vg across p to m;
BEGIN
    V == vg;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Resistor                                                 --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------

LIBRARY IEEE;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;

ENTITY R IS
    PORT (QUANTITY R : RESISTANCE := 1.0e+3; 
          TERMINAL p,m  : ELECTRICAL);
END ENTITY R;
ARCHITECTURE behav OF R IS
    QUANTITY v ACROSS i THROUGH p TO m;
BEGIN
    v == i*R;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Capacitor                                                 --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------

LIBRARY IEEE;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;

ENTITY C IS
    GENERIC (V0     : VOLTAGE := 0.0;
			 Use_V0 : BOOLEAN := true);
    PORT (QUANTITY C : CAPACITANCE := 1.0e-6; 
          TERMINAL p,m  : ELECTRICAL);
END ENTITY C;
ARCHITECTURE behav OF c IS
    QUANTITY v ACROSS i THROUGH p TO m;
    QUANTITY charge : CHARGE := C*V0;
BEGIN
    IF (domain = quiescent_domain) USE
      if (Use_V0) use
		  charge == C*V0;
          v == V0;
	  else
		  charge == C*v;
    	  i == 0.0;
	  end use;
    ELSE
      charge == C * v ;
      i == charge'dot;
   END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Limiter                                                  --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY LMT IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL := 0.0;
          QUANTITY UL : IN REAL := 0.0;
          QUANTITY LL : IN REAL := 0.0;
          QUANTITY VAL : OUT REAL);
END ENTITY LMT;
ARCHITECTURE behav OF LMT IS
  QUANTITY temp_val : REAL := 0.0;
  SIGNAL lower_crossing : BOOLEAN := FALSE;
  SIGNAL upper_crossing : BOOLEAN := FALSE;
BEGIN
    ASSERT (UL >= LL) REPORT "Upper Limit should be greater than Lower limit" SEVERITY error;

    lower_crossing <= NOT INPUT'ABOVE(LL);
    upper_crossing <= INPUT'ABOVE(UL);
    BREAK ON lower_crossing;
    BREAK ON upper_crossing;

    IF ((lower_crossing) AND (INPUT < LL)) USE
        temp_val == LL;
    ELSIF ((upper_crossing) AND (INPUT > UL)) USE
        temp_val == UL;
    ELSE
        temp_val == INPUT;
    END USE;
    VAL == temp_val'ZOH(TS);
END ARCHITECTURE;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Gain                                                     --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
ENTITY GAIN IS
    GENERIC (TS : REAL := 0.0); 
    PORT (QUANTITY INPUT : IN REAL := 0.0;
          QUANTITY KP : IN REAL := 1.0;
          QUANTITY VAL : OUT REAL);
END ENTITY GAIN;
ARCHITECTURE behav OF GAIN IS
BEGIN
	VAL == KP*INPUT'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Absolute Value                                           --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MATH_REAL.ALL;

ENTITY fktabs IS
    GENERIC (TS : REAL := 0.0);
    PORT (QUANTITY INPUT : IN REAL;
         QUANTITY VAL : OUT REAL);
END ENTITY fktabs;
ARCHITECTURE behav OF fktabs IS
  QUANTITY temp_val : REAL := 0.0;
BEGIN
  temp_val == abs(INPUT);
  VAL == temp_val'ZOH(TS);
END behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

---------- VHDLAMS MODEL mg2_mot_loss_map ----------
--------------   Copyright (C) 2019 OIC_Digital Twins Inc.  ----------------------

--This model is modeled by  Digital Twins Inc. using component of the open source library created by AK-30, ANSYS and is covered by this license agreement. 

--This model was provided by  Digital Twins Inc. to METI as a social contribution. 
--This model including any updates, modifications, revisions, copies, and documentation are copyrighted works of the Digital Twins Inc. 

--THIS MODEL IS LICENSED TO YOU "AS IT IS" AND WITH NO WARRANTIES, EXPRESSED OR IMPLIED. ALL COMPANIES CONTRIBUTING TO THIS LIBRARY SPECIFICALLY DISCLAIM
-- ALL IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. 
--  Digital Twins Inc  AND ALL COMPANIES  MUST NOT HAVE ANY RESPONSIBILITY FOR ANY DAMAGES, FINANCIAL OR LEGAL CLAIMS WHATEVER.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            | Kimitoshi Tsuji    2-19.11.13 Digital Twins Inc. |         | 
-- ----------------------------------------------------------------------------
library fundamentals_vda;
	use fundamentals_vda.tlu_vda.all;

---------- ENTITY DECLARATION mg2_mot_loss_map ----------
ENTITY	mg2_mot_loss_map IS

generic ( IN_TRQ : real_vector :=(-230.0,-207.0,-200.0,-175.0,-150.0,-125.0,-100.0,-75.0,-50.0,-25.0,0.0,25.0,50.0,75.0,100.0,125.0,150.0,175.0,200.0,207.0,230.0);  -- [Nm]
		  IN_RPM : real_vector :=(0.0,400.0,1000.0,1500.0,2000.0,2500.0,3000.0,3500.0,4000.0,4500.0,5000.0,5500.0,6000.0,6500.0,7000.0,8000.0,9000.0,10000.0,11000.0,12000.0,13500.0); --[rpm]
          OUT_MOTLOSS :real_vector := ( 15.76, 8.13, 7.06, 4.73, 3.23, 2.07, 1.27, 0.77, 0.40,0.11,0.00,0.11, 0.40, 0.80, 1.30, 2.10, 3.20, 4.70, 7.10, 8.10,15.80,  -- [kW]
										17.06, 8.52, 7.35, 4.89, 3.35, 2.16, 1.34, 0.81, 0.43,0.12,0.00,0.12, 0.43, 0.80, 1.30, 2.20, 3.40, 4.90, 7.40, 8.50,17.10,
										17.36, 8.69, 7.51, 5.03, 3.47, 2.27, 1.43, 0.90, 0.50,0.17,0.03,0.17, 0.50, 0.90, 1.40, 2.30, 3.50, 5.00, 7.50, 8.70,17.40,
										17.62, 8.85, 7.65, 5.15, 3.57, 2.36, 1.51, 0.96, 0.55,0.21,0.05,0.21, 0.55, 1.00, 1.50, 2.40, 3.60, 5.20, 7.70, 8.90,17.60,
										17.91, 9.03, 7.81, 5.28, 3.69, 2.46, 1.60, 1.04, 0.61,0.25,0.07,0.25, 0.61, 1.00, 1.60, 2.50, 3.70, 5.30, 7.80, 9.00,17.90,
										18.21, 9.22, 7.99, 5.42, 3.82, 2.57, 1.70, 1.12, 0.68,0.30,0.09,0.30, 0.68, 1.10, 1.70, 2.60, 3.80, 5.40, 8.00, 9.20,18.20,
										12.34, 9.18, 8.22, 5.62, 3.90, 2.71, 1.84, 1.20, 0.72,0.36,0.12,0.36, 0.72, 1.20, 1.80, 2.70, 3.90, 5.60, 8.20, 9.20,12.30,
										10.84, 8.88, 8.28, 6.15, 4.01, 2.88, 1.93, 1.29, 0.83,0.39,0.15,0.39, 0.83, 1.30, 1.90, 2.90, 4.00, 6.20, 8.30, 8.90,10.80,
										14.82,12.24,11.45, 8.65, 5.84, 3.04, 2.09, 1.39, 0.85,0.49,0.17,0.49, 0.85, 1.40, 2.10, 3.00, 5.80, 8.70,11.50,12.20,14.80,
										14.92,12.71,12.03, 9.62, 7.22, 4.81, 2.40, 1.49, 0.81,0.62,0.20,0.62, 0.81, 1.50, 2.40, 4.80, 7.20, 9.60,12.00,12.70,14.90,
										 9.32, 8.20, 7.86, 6.65, 5.44, 4.22, 3.01, 1.79, 0.80,0.81,0.24,0.81, 0.80, 1.80, 3.00, 4.20, 5.40, 6.70, 7.90, 8.20, 9.30,
										24.06,20.86,19.89,16.41,12.93, 9.46, 5.98, 2.50, 0.68,1.71,0.27,1.71, 0.68, 2.50, 6.00, 9.50,12.90,16.40,19.90,20.90,24.10,
										29.77,25.74,24.51,20.13,15.75,11.36, 6.98, 2.60, 1.23,0.67,0.31,0.67, 1.23, 2.60, 7.00,11.40,15.80,20.10,24.50,25.70,29.80,
										15.73,13.90,13.35,11.36, 9.37, 7.38, 5.39, 3.40, 1.41,0.71,0.36,0.71, 1.41, 3.40, 5.40, 7.40, 9.40,11.40,13.40,13.90,15.70,
										24.00,21.14,20.27,17.17,14.06,10.95, 7.85, 4.74, 1.63,0.78,0.42,0.78, 1.63, 4.70, 7.90,11.00,14.10,17.20,20.30,21.10,24.00,
										10.32, 9.27, 8.95, 7.81, 6.67, 5.53, 4.39, 3.25, 2.11,0.97,0.56,0.97, 2.11, 3.30, 4.40, 5.50, 6.70, 7.80, 9.00, 9.30,10.30,
										18.71,16.74,16.14,13.99,11.85, 9.71, 7.57, 5.43, 3.28,1.14,0.72,1.14, 3.28, 5.40, 7.60, 9.70,11.90,14.00,16.10,16.70,18.70,
										26.65,23.83,22.97,19.89,16.82,13.75,10.68, 7.60, 4.53,1.46,0.89,1.46, 4.53, 7.60,10.70,13.80,16.80,19.90,23.00,23.80,26.70,
										36.20,32.34,31.17,26.99,22.80,18.62,14.43,10.25, 6.06,1.87,1.06,1.87, 6.06,10.30,14.40,18.60,22.80,27.00,31.20,32.30,36.20,
										58.45,52.18,50.27,43.44,36.62,29.79,22.97,16.15, 9.32,2.50,1.23,2.50, 9.32,16.20,23.00,29.80,36.60,43.40,50.30,52.20,58.50,
										76.42,68.24,65.75,56.86,47.96,39.07,30.18,21.29,12.40,3.51,1.51,3.51,12.40,21.30,30.20,39.10,48.00,56.90,65.80,68.20,76.40));

port ( quantity q_in_trq :in real := 0.0;    -- [Nm]
       quantity q_in_rpm :in real := 0.0;    -- [rpm]
       quantity q_out_motloss :out real );   -- [kW]

END ENTITY mg2_mot_loss_map;

---------- ARCHITECTURE DECLARATION arch_mg2_mot_loss_map ----------
ARCHITECTURE arch_mg2_mot_loss_map OF mg2_mot_loss_map IS

    -- function that makes a value within bounds 
    function bounds  ( value, lower, upper : real ) return real is
     variable result : real;
    begin
	
	if value > upper then
		result := upper;
    elsif value < lower then
		result := lower;
	else
		result := value;
	end if;

    return result;
    end function bounds;

BEGIN

    q_out_motloss == lookup_2d(bounds(q_in_trq,-230.0,230.0),
							   bounds(q_in_rpm,0.0,13500.0),
							   IN_TRQ,
							   IN_RPM,
							   OUT_MOTLOSS);

END ARCHITECTURE arch_mg2_mot_loss_map;
---------- END VHDLAMS MODEL mg2_mot_loss_map ----------

--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

---------- VHDLAMS MODEL mg2_inv_loss_map ----------
--------------   Copyright (C) 2019 OIC_Digital Twins Inc.  ----------------------

--This model is modeled by  Digital Twins Inc. using component of the open source library created by AK-30, ANSYS and is covered by this license agreement. 

--This model was provided by  Digital Twins Inc. to METI as a social contribution. 
--This model including any updates, modifications, revisions, copies, and documentation are copyrighted works of the Digital Twins Inc. 

--THIS MODEL IS LICENSED TO YOU "AS IT IS" AND WITH NO WARRANTIES, EXPRESSED OR IMPLIED. ALL COMPANIES CONTRIBUTING TO THIS LIBRARY SPECIFICALLY DISCLAIM
-- ALL IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. 
--  Digital Twins Inc  AND ALL COMPANIES  MUST NOT HAVE ANY RESPONSIBILITY FOR ANY DAMAGES, FINANCIAL OR LEGAL CLAIMS WHATEVER.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            | Kimitoshi Tsuji    2-19.11.13 Digital Twins Inc. |         | 
-- ----------------------------------------------------------------------------
library fundamentals_vda;
	use fundamentals_vda.tlu_vda.all;

---------- ENTITY DECLARATION mg2_inv_loss_map ----------
ENTITY	mg2_inv_loss_map IS

generic ( IN_TRQ : real_vector :=(-230.0,-207.0,-200.0,-175.0,-150.0,-125.0,-100.0,-75.0,-50.0,-25.0,0.0,25.0,50.0,75.0,100.0,125.0,150.0,175.0,200.0,207.0,230.0);  -- [Nm]
		  IN_RPM : real_vector :=(0.0,400.0,1000.0,1500.0,2000.0,2500.0,3000.0,3500.0,4000.0,4500.0,5000.0,5500.0,6000.0,6500.0,7000.0,8000.0,9000.0,10000.0,11000.0,12000.0,13500.0); --[rpm]
          OUT_INVLOSS :real_vector := ( 3.58,2.06,1.83,1.32,0.97,0.68,0.47,0.32,0.20,0.08,0.00,0.08,0.20,0.30,0.50,0.70,1.00,1.30,1.80,2.10,3.60,
										3.81,2.13,1.88,1.34,0.99,0.69,0.48,0.33,0.21,0.09,0.00,0.09,0.21,0.30,0.50,0.70,1.00,1.30,1.90,2.10,3.80,
										3.84,2.13,1.88,1.35,0.99,0.69,0.48,0.33,0.21,0.09,0.00,0.09,0.21,0.30,0.50,0.70,1.00,1.40,1.90,2.10,3.80,
										3.86,2.14,1.89,1.35,0.99,0.70,0.48,0.33,0.21,0.09,0.00,0.09,0.21,0.30,0.50,0.70,1.00,1.40,1.90,2.10,3.90,
										3.88,2.15,1.89,1.35,0.99,0.70,0.48,0.33,0.21,0.09,0.00,0.09,0.21,0.30,0.50,0.70,1.00,1.40,1.90,2.20,3.90,
										3.90,2.15,1.90,1.35,0.99,0.70,0.48,0.33,0.21,0.09,0.00,0.09,0.21,0.30,0.50,0.70,1.00,1.40,1.90,2.20,3.90,
										3.90,2.11,1.91,1.36,0.98,0.70,0.49,0.33,0.20,0.09,0.00,0.09,0.20,0.30,0.50,0.70,1.00,1.40,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,0.97,0.71,0.48,0.33,0.21,0.08,0.00,0.08,0.21,0.30,0.50,0.70,1.00,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,0.73,0.50,0.33,0.19,0.10,0.00,0.10,0.19,0.30,0.50,0.70,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,0.57,0.35,0.15,0.13,0.00,0.13,0.15,0.40,0.60,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,0.68,0.42,0.12,0.17,0.00,0.17,0.12,0.40,0.70,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,1.30,0.58,0.04,0.44,0.00,0.44,0.04,0.60,1.30,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,1.44,0.55,0.25,0.09,0.00,0.09,0.25,0.60,1.40,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,1.44,0.69,0.28,0.10,0.02,0.10,0.28,0.70,1.40,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,1.44,0.92,0.31,0.11,0.03,0.11,0.31,0.90,1.40,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,1.44,0.92,0.35,0.15,0.07,0.15,0.35,0.90,1.40,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,1.44,0.92,0.53,0.16,0.10,0.16,0.53,0.90,1.40,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,1.44,0.92,0.66,0.19,0.13,0.19,0.66,0.90,1.40,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,1.44,0.92,0.78,0.23,0.15,0.23,0.78,0.90,1.40,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,1.44,0.92,1.04,0.28,0.17,0.28,1.04,0.90,1.40,1.10,1.40,1.50,1.90,2.10,3.90,
										3.90,2.11,1.91,1.45,1.37,1.11,1.44,0.92,1.43,0.35,0.20,0.35,1.43,0.90,1.40,1.10,1.40,1.50,1.90,2.10,3.90));

port ( quantity q_in_trq :in real := 0.0;    -- [Nm]
       quantity q_in_rpm :in real := 0.0;    -- [rpm]
       quantity q_out_invloss :out real );   -- [kW]

END ENTITY mg2_inv_loss_map;

---------- ARCHITECTURE DECLARATION arch_mg2_inv_loss_map ----------
ARCHITECTURE arch_mg2_inv_loss_map OF mg2_inv_loss_map IS

    -- function that makes a value within bounds 
    function bounds  ( value, lower, upper : real ) return real is
     variable result : real;
    begin
	
	if value > upper then
		result := upper;
    elsif value < lower then
		result := lower;
	else
		result := value;
	end if;

    return result;
    end function bounds;

BEGIN

    q_out_invloss == lookup_2d(bounds(q_in_trq,-230.0,230.0),
							   bounds(q_in_rpm,0.0,13500.0),
							   IN_TRQ,
							   IN_RPM,
							   OUT_INVLOSS);

END ARCHITECTURE arch_mg2_inv_loss_map;
---------- END VHDLAMS MODEL mg2_inv_loss_map ----------

--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

library ieee;
--library fundamentals_vda;
    use ieee.electrical_systems.all;
--    use fundamentals_vda.tlu_vda.all;
	USE IEEE.MATH_REAL.ALL;

ENTITY mg2_power_calc IS
	PORT (
	QUANTITY t : IN real := 0.0;
	QUANTITY n : IN real := 0.0;
	QUANTITY loss : IN real := 0.0;
	QUANTITY loss2 : IN real := 0.0;    -- ADD 2008.5.18 LK kido
	QUANTITY kinshi_flg : IN real := 0.0;
	QUANTITY power : OUT real);
END ENTITY mg2_power_calc;
ARCHITECTURE behav OF mg2_power_calc IS

BEGIN


	if( kinshi_flg > 0.5) use
		power == 0.0;


	else

	power == ((n*t)+((loss+loss2)*1000.0));    

	end use;

END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY Macro3_13 IS
	PORT (
		QUANTITY kinshi_flg : IN REAL := 0.0;
		QUANTITY pmg2 : OUT REAL;
		QUANTITY tmg2 : IN REAL := 0.0;
		QUANTITY nmg2 : IN REAL := 0.0 
	);
BEGIN 
END ENTITY Macro3_13;

ARCHITECTURE struct OF Macro3_13 IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
	QUANTITY Q_5 : real := 0.0;
	QUANTITY Q_6 : real := 0.0;
	QUANTITY Q_7 : real := 0.0;
BEGIN
	lmt1 : ENTITY WORK.lmt(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_6 , ll => -240.0 , ul => 240.0 , input => tmg2 );

	gain1 : ENTITY WORK.gain(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_7 , kp => 9.5493046514663 , input => nmg2 );

	fktabs1 : ENTITY WORK.fktabs(behav)
		GENERIC MAP ( ts => 0.0 )
		PORT MAP ( val => Q_5 , input => Q_7 );

	mg2_mot_loss_map1 : ENTITY WORK.mg2_mot_loss_map(arch_mg2_mot_loss_map)
		PORT MAP ( q_out_motloss => Q_4 , q_in_rpm => Q_5 , q_in_trq => Q_6 );

	mg2_inv_loss_map1 : ENTITY WORK.mg2_inv_loss_map(arch_mg2_inv_loss_map)
		PORT MAP ( q_out_invloss => Q_3 , q_in_rpm => Q_5 , q_in_trq => Q_6 );

	mg2_power_calc : ENTITY WORK.mg2_power_calc(behav)
		PORT MAP ( power => Q_2 , kinshi_flg => kinshi_flg , loss2 => Q_3 , loss => Q_4 , n => nmg2 , t => tmg2 );

	pmg2 == Q_2;
END ARCHITECTURE struct;
----------------------------------------------------------------------

--///////////////////////////////////////////////////////////////////////////////////////////////////

--------------   Copyright (C) 2019 OIC_Digital Twins Inc.  ----------------------

--This model is modeled by  Digital Twins Inc. using component of the open source library created by AK-30, ANSYS and is covered by this license agreement. 

--This model was provided by  Digital Twins Inc. to METI as a social contribution. 
--This model including any updates, modifications, revisions, copies, and documentation are copyrighted works of the Digital Twins Inc. 

--THIS MODEL IS LICENSED TO YOU "AS IT IS" AND WITH NO WARRANTIES, EXPRESSED OR IMPLIED. ALL COMPANIES CONTRIBUTING TO THIS LIBRARY SPECIFICALLY DISCLAIM
-- ALL IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. 
--  Digital Twins Inc  AND ALL COMPANIES  MUST NOT HAVE ANY RESPONSIBILITY FOR ANY DAMAGES, FINANCIAL OR LEGAL CLAIMS WHATEVER.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            | Kimitoshi Tsuji    2-19.11.13 Digital Twins Inc. |         | 
-- ----------------------------------------------------------------------------


LIBRARY IEEE;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;
USE ieee.mechanical_systems.all;
USE IEEE.MATH_REAL.ALL;


ENTITY i_calc1 IS
	GENERIC (
		
		MAX_V : real := 500.0;
		MIN_V : real := 1.0;
		LMT_I : real := 100.0);

    PORT(   QUANTITY out_i : out real;

			QUANTITY v_in : in real;
			QUANTITY p_in : in real :=0.0);

END ENTITY i_calc1;
ARCHITECTURE behav OF i_calc1 IS

QUANTITY tmp_i : real ;
QUANTITY tmp_v : real ;

BEGIN


tmp_v == realmin(realmax(v_in, MIN_V), MAX_V);
	if(tmp_v = 0.0) use 
	tmp_i == 0.0 ; 
	else 
	tmp_i == p_in/ tmp_v  ;
 	end use ; 
out_i == realmin(realmax(tmp_i, -LMT_I), LMT_I) ;


END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Current Source                                           --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------

LIBRARY IEEE;
USE IEEE.MATH_REAL.MATH_2_PI;
USE IEEE.ELECTRICAL_SYSTEMS.ALL;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY I IS 
    PORT (QUANTITY I : IN CURRENT := 1.0; 
          QUANTITY AC_MAG : IN CURRENT := 1.0e-3;
          QUANTITY AC_PHASE : IN ANGLE := 0.0;
          TERMINAL p,m: ELECTRICAL);
END ENTITY I;
ARCHITECTURE behav OF I IS
    QUANTITY v ACROSS ic THROUGH p TO m;
    QUANTITY ac_spec : real SPECTRUM AC_MAG, MATH_2_PI*AC_PHASE/360.0;
BEGIN
    IF (domain = quiescent_domain) OR (domain = time_domain) USE
	  ic == I;
    ELSE
      ic == ac_spec;
    END USE;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY MotorGenerator_Elec IS
	PORT (
		TERMINAL EL_MG_PNT_p : ELECTRICAL;
		TERMINAL EL_MG_PNT_m : ELECTRICAL;
		QUANTITY kaisei_kinshi : IN REAL := 0.0;
		QUANTITY tmg2 : IN REAL := 0.0;
		QUANTITY nmg2 : IN REAL := 0.0;
		QUANTITY loss_Watt2 : OUT REAL 
	);
BEGIN 
END ENTITY MotorGenerator_Elec;

ARCHITECTURE struct OF MotorGenerator_Elec IS
	TERMINAL net_15 : ELECTRICAL;
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
BEGIN
	vm1 : ENTITY WORK.vm(behav)
		PORT MAP ( m => EL_MG_PNT_m, p => net_15, v => Q_4 );

	r2 : ENTITY WORK.r(behav)
		PORT MAP ( m => net_15, p => EL_MG_PNT_p, r => 0.01 );

	c1 : ENTITY WORK.c(behav)
		GENERIC MAP ( use_v0 => true , v0 => 0.0 )
		PORT MAP ( m => EL_MG_PNT_m, p => net_15, c => 0.001 );

	PMG2_calculation: ENTITY WORK.Macro3_13(struct)
		PORT MAP ( kinshi_flg => kaisei_kinshi , pmg2 => Q_3 , tmg2 => tmg2 , nmg2 => nmg2 );

	r1 : ENTITY WORK.r(behav)
		PORT MAP ( m => EL_MG_PNT_m, p => net_15, r => 100000.0 );

	i_calc11 : ENTITY WORK.i_calc1(behav)
		GENERIC MAP ( lmt_i => 150.0 )
		PORT MAP ( p_in => Q_3 , v_in => Q_4 , out_i => Q_2 );

	i2 : ENTITY WORK.i(behav)
		PORT MAP ( m => EL_MG_PNT_m, p => net_15, ac_phase => 0.0 , ac_mag => 0.001 , i => Q_2 );

	loss_Watt2 == Q_3;
END ARCHITECTURE struct;
----------------------------------------------------------------------


LIBRARY ieee;
USE ieee.all;

ENTITY MG_PNT IS
	PORT (
		TERMINAL EL_MG_PNT_m : ELECTRICAL;
		TERMINAL EL_MG_PNT_p : ELECTRICAL;
		TERMINAL MRV_MG_PNT : ROTATIONAL_V;
		QUANTITY tgt_Trq_MG_CNT_Nm : IN REAL := 0.0 
	);
BEGIN 
END ENTITY MG_PNT;

ARCHITECTURE struct OF MG_PNT IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
BEGIN
	MotorGenerator_Mecha: ENTITY WORK.MotorGenerator_Mecha(struct)
		PORT MAP ( mrv_mg_pnt => MRV_MG_PNT, tgt_Trq_MG_CNT_Nm => tgt_Trq_MG_CNT_Nm , tmg2 => Q_2 , nmg2 => Q_3 );

	MotorGenerator_Elec: ENTITY WORK.MotorGenerator_Elec(struct)
		PORT MAP ( el_mg_pnt_p => EL_MG_PNT_p, el_mg_pnt_m => EL_MG_PNT_m, kaisei_kinshi => 0.0 , tmg2 => Q_2 , nmg2 => Q_3 , loss_Watt2 => Q_4 );
END ARCHITECTURE struct;
----------------------------------------------------------------------




