--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Mass                                                     --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY mass_tr IS
  GENERIC(
    s0 : DISPLACEMENT := 0.0;
    v0 : VELOCITY := 0.0);
  PORT(
    QUANTITY m : MASS := 1.0;
    TERMINAL tr1 : TRANSLATIONAL_V);
END ENTITY mass_tr;
ARCHITECTURE behav OF mass_tr IS
  QUANTITY v ACROSS f THROUGH tr1 TO translational_v_ref;
  QUANTITY s : DISPLACEMENT;
  QUANTITY acc : ACCELERATION;
BEGIN
  IF (domain = quiescent_domain) USE
    s == s0;
    v == v0;
  ELSE
    s'dot == v;
    v'dot == acc;
  END USE;
    f == m*acc;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

--  --------------------------------------------------------------------------
--                                                                      --
-- Copyright (c) 2004 by ANSOFT Corp.  All rights reserved.             --
--                                                                      --
-- This source file may be used and distributed without restriction     --
-- provided that this copyright statement is not removed from the file  --
-- and that any derivative work contains this copyright notice.         --
--                                                                      --
-- Model name: Velocity Sensor                                          --
-- Library: Basic_VHDLAMS                                               --
--                                                                      --
-- ----------------------------------------------------------------------------
--                 Warranty
-- ----------------------------------------------------------------------------
-- ANSOFT Corporation makes no warranty of any kind with regard to the use of
-- this Software, either expressed or implied, including, but not limited to 
-- the fitness for a particular purpose.
-- 
-- ----------------------------------------------------------------------------
-- Modification History : 
-- ----------------------------------------------------------------------------
-- Version No:|Auth:| Mod.Date:| Changes Made:
--            |     |          | 
-- ----------------------------------------------------------------------------
LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;

ENTITY vm_tr IS
  PORT(
    QUANTITY v : OUT VELOCITY;
    TERMINAL tr1: TRANSLATIONAL_V);
END ENTITY vm_tr;
ARCHITECTURE behav OF vm_tr IS
  QUANTITY v_val ACROSS tr1 TO translational_v_ref;
BEGIN
 v_val == v;
END ARCHITECTURE behav;
--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

-----------------------------------------------------------------------------------------------------------------------
--------------   Copyright (C) 2019 OIC_Digital Twins Inc.  ----------------------

--This model is a component of the open source library created by AK-30, ANSYS, 
--Digital Twins Inc. and is covered by this license agreement. 
--This model was provided by  Digital Twins Inc to METI.
-- as a social contribution. This model including any updates, modifications, revisions, 
--copies, and documentation are copyrighted works of the Digital Twins Inc. 
--Use of this model indicates your complete and unconditional acceptance of the terms and
-- conditions set forth in this license agreement.
-- OIC Digital Twins Inc grants a non-exclusive license to use, reproduce, modify 
--and distribute this model under the condition, that:
--(a) no fee or other consideration is charged for any distribution except compilations distributed
-- in accordance with Section (d) of this license agreement;
--(b) the comment text embedded in this model is included verbatim in each copy of this model 
--made or distributed by you, whether or not such version is modified;
--(c) any modified version must include a conspicuous notice that this model has been modified
-- and the date of modification; and
--(d) any compilations sold by you that include this model must include a conspicuous notice 
--that this model is available from the JSAE in its original form at no charge.

--THIS MODEL IS LICENSED TO YOU "AS IT IS" AND WITH NO WARRANTIES, EXPRESSED OR
-- IMPLIED. ALL COMPANIES CONTRIBUTING TO THIS LIBRARY SPECIFICALLY DISCLAIM
-- ALL IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. 
-- OIC Digital Twins Inc. AND ALL COMPANIES ORGANIZED WITHIN MUST NOT 
--HAVE ANY RESPONSIBILITY FOR ANY DAMAGES, FINANCIAL OR LEGAL CLAIMS WHATEVER.
------------------------------------------------------------------------------------------------------------------------

----------------------------------------------------------------------------------
-- Dependencies: 
-- --------------------------------------------------------------------
-- Logical Library         Design unit
-- --------------------------------------------------------------------
--
-- Date 2019.10.26
--
-- Author(s):
-- Kimitoshi Tsuji
--
-- 
-- ------------------------------------------------------------------
-- Version  Simulator      Version   OS    Validator      Date
-- ------------------------------------------------------------------
--  1.0      
--
--
-- Modification History:
-- ------------------------------------------------------------------
-- Version  Author            Date           Description
-- ------------------------------------------------------------------


-- 



LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;
USE IEEE.ENERGY_SYSTEMS.POWER;

ENTITY load_vehicle_00_a IS   
  PORT(
	QUANTITY mass   	: IN mass := 1500.0;
    QUANTITY v_vehicle   : IN VELOCITY := 1.21;
    QUANTITY k_v2        : IN REAL    := 0.04279;
    QUANTITY k_v         : IN REAL    := 1.0;
    QUANTITY k_c         : IN REAL    := 199.3;
	QUANTITY CTL         : IN REAL    := 0.0;
    QUANTITY power_load : OUT Power;
    
    TERMINAL tr1 : TRANSLATIONAL_V);

END ENTITY load_vehicle_00_a;
ARCHITECTURE behav OF load_vehicle_00_a IS

  QUANTITY v ACROSS f THROUGH  tr1 to TRANSLATIONAL_V_REF ;
  QUANTITY v_kmph : DISPLACEMENT;
  QUANTITY s : DISPLACEMENT;

BEGIN

 v_kmph == v_vehicle * 3.6;

if CTL = 0.0 use

  if v_vehicle'ABOVE(0.001) use

 f == k_v2*v_kmph**2 + k_v*v_kmph + k_c;
  else
      f == 0.0;
  end use;

else

f==0.0;
end use;
  v == s'dot;
 
  power_load == f * v_vehicle;

END ARCHITECTURE behav;

--//////////////////////////////////////////////////////////////////////////////////////////////////

--///////////////////////////////////////////////////////////////////////////////////////////////////

-----------------------------------------------------------------------------------------------------------------------
--------------   Copyright (C) 2019 OIC_Digital Twins Inc.  ----------------------

--This model is a component of the open source library created by AK-30, ANSYS, 
--Digital Twins Inc. and is covered by this license agreement. 
--This model was provided by  Digital Twins Inc to METI.
-- as a social contribution. This model including any updates, modifications, revisions, 
--copies, and documentation are copyrighted works of the Digital Twins Inc. 
--Use of this model indicates your complete and unconditional acceptance of the terms and
-- conditions set forth in this license agreement.
-- OIC Digital Twins Inc grants a non-exclusive license to use, reproduce, modify 
--and distribute this model under the condition, that:
--(a) no fee or other consideration is charged for any distribution except compilations distributed
-- in accordance with Section (d) of this license agreement;
--(b) the comment text embedded in this model is included verbatim in each copy of this model 
--made or distributed by you, whether or not such version is modified;
--(c) any modified version must include a conspicuous notice that this model has been modified
-- and the date of modification; and
--(d) any compilations sold by you that include this model must include a conspicuous notice 
--that this model is available from the JSAE in its original form at no charge.

--THIS MODEL IS LICENSED TO YOU "AS IT IS" AND WITH NO WARRANTIES, EXPRESSED OR
-- IMPLIED. ALL COMPANIES CONTRIBUTING TO THIS LIBRARY SPECIFICALLY DISCLAIM
-- ALL IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. 
-- OIC Digital Twins Inc. AND ALL COMPANIES ORGANIZED WITHIN MUST NOT 
--HAVE ANY RESPONSIBILITY FOR ANY DAMAGES, FINANCIAL OR LEGAL CLAIMS WHATEVER.
------------------------------------------------------------------------------------------------------------------------

----------------------------------------------------------------------------------
-- Dependencies: 
-- --------------------------------------------------------------------
-- Logical Library         Design unit
-- --------------------------------------------------------------------
--
-- Date 2019.10.26
--
-- Author(s):
-- Kimitoshi Tsuji
--
-- 
-- ------------------------------------------------------------------
-- Version  Simulator      Version   OS    Validator      Date
-- ------------------------------------------------------------------
--  1.0      
--
--
-- Modification History:
-- ------------------------------------------------------------------
-- Version  Author            Date           Description
-- ------------------------------------------------------------------

-- 

LIBRARY IEEE;
USE IEEE.MECHANICAL_SYSTEMS.ALL;
USE IEEE.ENERGY_SYSTEMS.POWER;

ENTITY resistance_air_00_b IS   
  PORT(

  	QUANTITY CTL  	: IN real := 0.0;
	QUANTITY mass   	: IN mass := 1500.0;
    QUANTITY v_vehicle   : IN VELOCITY := 1.21;
    QUANTITY dens_air    : IN REAL := 1.21;
    QUANTITY c_airresi   : IN REAL    := 0.413;
    QUANTITY squ_project : IN REAL    := 2.606;

    QUANTITY power_air_resi : OUT Power;
    
    TERMINAL tr1 : TRANSLATIONAL_V);

END ENTITY resistance_air_00_b;
ARCHITECTURE behav OF resistance_air_00_b IS

  QUANTITY v ACROSS f THROUGH  tr1 to TRANSLATIONAL_V_REF ;
  QUANTITY s : DISPLACEMENT;

BEGIN

if CTL > 0.0 use
  
f == 0.5*dens_air*c_airresi*squ_project*v_vehicle*v_vehicle;

else 
f==0.0;
end use;
 v == s'dot;
 
  power_air_resi == f * v;
END ARCHITECTURE behav;

--//////////////////////////////////////////////////////////////////////////////////////////////////


LIBRARY ieee;
USE ieee.all;

ENTITY VL_PNT IS
	PORT (
		TERMINAL MTV_VL_PNT : TRANSLATIONAL_V;
		QUANTITY Cd : IN REAL := 0.0;
		QUANTITY Road_Load_Select_Switch : IN REAL := 0.0;
		QUANTITY Road_Load_V : IN REAL := 0.0;
		QUANTITY Road_Load_V2 : IN REAL := 0.0;
		QUANTITY Road_Load_C : IN REAL := 0.0;
		QUANTITY rou : IN REAL := 0.0;
		QUANTITY M : IN REAL := 0.0;
		QUANTITY v_VL_PNT_mps : OUT REAL;
		QUANTITY A : IN REAL := 0.0 
	);
BEGIN 
END ENTITY VL_PNT;

ARCHITECTURE struct OF VL_PNT IS
	QUANTITY Q_2 : real := 0.0;
	QUANTITY Q_3 : real := 0.0;
	QUANTITY Q_4 : real := 0.0;
BEGIN
	mass_vehicle : ENTITY WORK.mass_tr(behav)
		GENERIC MAP ( v0 => 0.0 , s0 => 0.0 )
		PORT MAP ( tr1 => MTV_VL_PNT, m => M );

	Vehicle_speed_ms : ENTITY WORK.vm_tr(behav)
		PORT MAP ( tr1 => MTV_VL_PNT, v => Q_3 );

	load_vehicle_00_a1 : ENTITY WORK.load_vehicle_00_a(behav)
		PORT MAP ( tr1 => MTV_VL_PNT, power_load => Q_4 , ctl => Road_Load_Select_Switch , k_c => Road_Load_C , k_v => Road_Load_V , k_v2 => Road_Load_V2 , v_vehicle => Q_3 , mass => M );

	resistance_air_00_b1 : ENTITY WORK.resistance_air_00_b(behav)
		PORT MAP ( tr1 => MTV_VL_PNT, power_air_resi => Q_2 , squ_project => A , c_airresi => Cd , dens_air => rou , v_vehicle => Q_3 , mass => M , ctl => Road_Load_Select_Switch );

	v_VL_PNT_mps == Q_3;
END ARCHITECTURE struct;
----------------------------------------------------------------------


